@@ -118,6 +118,7 @@ from ._api import (
     get_rest_projects,
     get_rest_entity_by_id,
     get_rest_folder,
+    get_rest_folders,
     get_rest_task,
     get_rest_product,
     get_rest_version,
@@ -329,6 +330,7 @@ __all__ = (
     "get_rest_projects",
     "get_rest_entity_by_id",
     "get_rest_folder",
+    "get_rest_folders",
     "get_rest_task",
     "get_rest_product",
     "get_rest_version",
