@@ -219,6 +219,7 @@ class EntityHub(object):
                 entity_data = self._connection.get_task_by_id(
                     self.project_name,
                     entity_id,
+                    fields=self._get_task_fields(),
                     own_attributes=True
                 )
             else:
@@ -604,15 +605,12 @@ class EntityHub(object):
         folder_fields.add("hasProducts")
         if self._allow_data_changes:
             folder_fields.add("data")
-        folder_fields |= {"status", "tags"}
         return folder_fields
 
     def _get_task_fields(self):
-        task_fields = set(
+        return set(
             self._connection.get_default_fields_for_type("task")
         )
-        task_fields |= {"status", "tags"}
-        return task_fields
 
     def query_entities_from_server(self):
         """Query whole project at once."""
@@ -2587,6 +2585,7 @@ class FolderEntity(BaseEntity):
 
     def lock(self):
         super(FolderEntity, self).lock()
+        self._orig_label = self._get_label_value()
         self._orig_folder_type = self._folder_type
         self._orig_status = self._status
         self._orig_tags = copy.deepcopy(self._tags)
@@ -2610,10 +2609,7 @@ class FolderEntity(BaseEntity):
         if self._orig_tags != self._tags:
             changes["tags"] = self._tags
 
-        label = self._label
-        if self._name == label:
-            label = None
-
+        label = self._get_label_value()
         if label != self._orig_label:
             changes["label"] = label
 
@@ -2657,6 +2653,10 @@ class FolderEntity(BaseEntity):
             "folderType": self.folder_type,
             "parentId": parent_id,
         }
+        label = self._get_label_value()
+        if label:
+            output["label"] = label
+
         attrib = self.attribs.to_dict()
         if attrib:
             output["attrib"] = attrib
@@ -2681,6 +2681,18 @@ class FolderEntity(BaseEntity):
             output["data"] = self._data
         return output
 
+    def _get_label_value(self):
+        """Get label value that will be used for operations.
+
+        Returns:
+            Union[str, None]: Label value.
+
+        """
+        label = self._label
+        if not label or self._name == label:
+            return None
+        return label
+
 
 class TaskEntity(BaseEntity):
     """Entity representing a task on AYON server.
@@ -2736,6 +2748,7 @@ class TaskEntity(BaseEntity):
 
     def lock(self):
         super(TaskEntity, self).lock()
+        self._orig_label = self._get_label_value()
         self._orig_task_type = self._task_type
         self._orig_status = self._status
         self._orig_tags = copy.deepcopy(self._tags)
@@ -2821,10 +2834,7 @@ class TaskEntity(BaseEntity):
         if self._orig_tags != self._tags:
             changes["tags"] = self._tags
 
-        label = self._label
-        if self._name == label:
-            label = None
-
+        label = self._get_label_value()
         if label != self._orig_label:
             changes["label"] = label
 
@@ -2857,6 +2867,10 @@ class TaskEntity(BaseEntity):
             "folderId": self.parent_id,
             "attrib": self.attribs.to_dict(),
         }
+        label = self._get_label_value()
+        if label:
+            output["label"] = label
+
         attrib = self.attribs.to_dict()
         if attrib:
             output["attrib"] = attrib
@@ -2876,3 +2890,15 @@ class TaskEntity(BaseEntity):
         ):
             output["data"] = self._data
         return output
+
+    def _get_label_value(self):
+        """Get label value that will be used for operations.
+
+        Returns:
+            Union[str, None]: Label value.
+
+        """
+        label = self._label
+        if not label or self._name == label:
+            return None
+        return label
